using System.Collections.Generic;
using System.Linq;

using ArtOfTest.Common;
using ArtOfTest.WebAii.Core;
using ArtOfTest.WebAii.TestTemplates;
using ArtOfTest.WebAii.Silverlight;
using ArtOfTest.WebAii.Silverlight.UI;

using NUnit.Framework;
using Core = NUnit.Core;
using System.Threading;
using ArtOfTest.WebAii.Win32.Dialogs;

namespace QuickStarts_NUnit_CS
{
    /// <summary>
    /// Summary description for WebAiiVSUnitTest1
    /// </summary>
    [TestFixture]
    public class SilverlightSample : BaseTest
    {
        #region Additional test attributes

        // Use TestInitialize to run code before running each test
        [SetUp]
        public void MyTestInitialize()
        {
            #region WebAii Initialization

            // Initializes WebAii manager to be used by the test case.
            // If a WebAii configuration section exists, settings will be
            // loaded from it. Otherwise, will create a default settings
            // object with system defaults.
            //
            // Note: We are passing in a delegate to the NUnit's TestContext.Out.
            // WriteLine() method. This way any logging
            // done from WebAii (i.e. Manager.Log.WriteLine()) is
            // automatically logged to same output as NUnit.
            //
            // If you do not care about unifying the log, then you can simply
            // initialize the test by calling Initialize() with no parameters;
            // that will cause the log location to be picked up from the config
            // file if it exists or will use the default system settings.
            // You can also use Initialize(LogLocation) to set a specific log
            // location for this test.
            //Initialize(new TestContextWriteLine(Core.TestContext.Out.WriteLine));

            // If you need to override any other settings coming from the
            // config section or you don't have a config section, you can
            // comment the 'Initialize' line above and instead use the
            // following:

            // This will get a new Settings object. If a configuration
            // section exists, then settings from that section will be
            // loaded

            Settings settings = GetSettings();

            // Override the settings you want. For example:
            settings.EnableSilverlight = true;
            settings.UnexpectedDialogAction = UnexpectedDialogAction.DoNotHandle;
            // Now call Initialize again with your updated settings object
            Initialize(settings, new TestContextWriteLine(Core.TestContext.Out.WriteLine));

            #endregion
        }

        // Use TestCleanup to run code after each test has run
        [TearDown]
        public void MyTestCleanup()
        {
            #region WebAii CleanUp

            // Shuts down WebAii manager and closes all browsers currently running
            this.CleanUp();

            #endregion
        }

        #endregion

        [Test]
        [Description("Automate a complex Silverlight application")]
        public void HealthCareDemo()
        {

            #region ## Launch the application ##
            Manager.Settings.ExecutionDelay = 10;

            Manager.LaunchNewBrowser(BrowserType.InternetExplorer);
            System.Drawing.Point loc = ActiveBrowser.Window.Location;
            ActiveBrowser.NavigateTo("http://jliang:7080");


            ActiveBrowser.Window.Move(new System.Drawing.Rectangle(loc, new System.Drawing.Size(1024, 768)), true);
            // Get an instance of the running Silverlight Application.
            SilverlightApp app = ActiveBrowser.SilverlightApps()[0];

            #endregion

            #region ## Admin Console ##

            TextBox usernameTB = app.FindName<TextBox>("nameBox");
            usernameTB.User.TypeText("admin", 100);

            PasswordBox passwordTB = app.FindName<PasswordBox>("passwordBox");
            passwordTB.User.TypeText("admin", 100);

            Button LogInButton = app.FindName<Button>("OKButton");
            LogInButton.User.Click();

            Thread.Sleep(5000);

            FrameworkElement temp = app.Find.ByName("fileManagementTab");
            temp.Wait.ForExists(10000);
            

            temp.User.Click();
            Thread.Sleep(5000);
            app.RefreshVisualTrees();
            app.FindName("uploadButton").User.Click();

            Thread.Sleep(5000);
            app.RefreshVisualTrees();

            FrameworkElement fileNameTextBox = app.FindName<TextBox>("nameTextBox");
            fileNameTextBox.Wait.ForVisible();

            FileUploadDialog uploadDialog = new FileUploadDialog(ActiveBrowser, @"c:\bar.emf", DialogButton.OPEN);
            
            Manager.DialogMonitor.AddDialog(uploadDialog);
            Manager.DialogMonitor.Start();

            app.FindName("browseButton").User.Click();
            app.RefreshVisualTrees();

            uploadDialog.WaitUntilHandled();
            Manager.DialogMonitor.RemoveDialog(uploadDialog);
            Manager.DialogMonitor.Stop();

            #endregion

        }
    }
}
